@@ -41,9 +41,13 @@ from .discriminators import (
     plot_xdata,
 )
 from .filter_functions import plot_filter_functions
-from .style import get_qctrl_style
+from .style import (
+    QCTRL_STYLE_COLORS,
+    get_qctrl_style,
+)
 
 __all__ = [
+    "QCTRL_STYLE_COLORS",
     "display_bloch_sphere",
     "display_bloch_sphere_from_bloch_vectors",
     "display_bloch_sphere_from_density_matrices",
@@ -57,4 +61,4 @@ __all__ = [
     "plot_xdata",
 ]
 
-__version__ = "2.8.0"
+__version__ = "2.10.0"
