@@ -41,21 +41,27 @@ def plot_controls(
         will be overridden by this method.
     controls : dict
         The dictionary of controls to plot. The keys should be the names of the controls, and the
-        values the list of segments representing the pulse of that control. Each such segment must
-        be a dictionary with 'value' and 'duration' keys, giving the value (possibly complex, in the
-        units specified by `unit_symbol`) and duration (in seconds) of that segment of the pulse.
-        For example, the following would be a valid ``controls`` input::
+        values represent the pulse by either (1) a dictionary with the 'durations' and 'values' for
+        that control, or (2) a list of segments, each a dictionary with 'duration' and 'value' keys.
+        The durations must be in seconds and the values (possibly complex) in the units specified by
+        `unit_symbol`.
+        For example, the following two ``controls`` inputs would be valid (and equivalent)::
 
-            {
-             'Clock': [
-                 {'duration': 1.0, 'value': -0.5},
-                 {'duration': 1.0, 'value': 0.5},
-                 {'duration': 2.0, 'value': -1.5},
-             ],
-             'Microwave': [
-                 {'duration': 0.5, 'value': 0.5 + 1.5j},
-                 {'duration': 1.0, 'value': 0.2 - 0.3j},
-             ],
+            controls={
+              "Clock": {"durations": [1.0, 1.0, 2.0], "values": [-0.5, 0.5, -1.5]},
+              "Microwave": {"durations": [0.5, 1.0], "values": [0.5 + 1.5j, 0.2 - 0.3j]},
+            }
+
+            controls={
+              'Clock': [
+                {'duration': 1.0, 'value': -0.5},
+                {'duration': 1.0, 'value': 0.5},
+                {'duration': 2.0, 'value': -1.5},
+              ],
+              'Microwave': [
+                {'duration': 0.5, 'value': 0.5 + 1.5j},
+                {'duration': 1.0, 'value': 0.2 - 0.3j},
+              ],
             }
 
     polar : bool, optional
@@ -77,12 +83,19 @@ def plot_controls(
         If any of the input parameters are invalid.
     """
     plots_data: List[Any] = []
-    for name, segments in controls.items():
-        durations = []
-        values = []
-        for segment in segments:
-            durations.append(segment["duration"])
-            values.append(segment["value"])
+    for name, control in controls.items():
+        # Process each control depending whether it's passed as a list of segments...
+        if isinstance(control, list):
+            durations = []
+            values = []
+            for segment in control:
+                durations.append(segment["duration"])
+                values.append(segment["value"])
+        # ...or a durations/values dictionary.
+        else:
+            durations = control["durations"]
+            values = control["values"]
+        # Create plot data for the control.
         values = np.array(values)
         plots_data = plots_data + _create_plots_data_from_control(
             name, durations, values, polar, unit_symbol, two_pi_factor
@@ -169,23 +182,31 @@ def plot_smooth_controls(
         will be overridden by this method.
     controls : dict
         The dictionary of controls to plot. The keys should be the names of the controls, and the
-        values the list of samples representing the pulse of that control. Each such sample must
-        be a dictionary with 'value' and 'time' keys, giving the value (possibly complex, in the
-        units specified by `unit_symbol`)  and time (in seconds) of that sample of the pulse. The
-        times must be in increasing order.
-        For example, the following would be a valid ``controls`` input::
+        values represent the pulse by either (1) a dictionary with the 'times' and 'values' for
+        that control, or (2) a list of samples, each a dictionary with 'time' and 'value' keys.
+        The times must be in seconds and the values (possibly complex) in the units specified by
+        `unit_symbol`.
+        For example, the following two ``controls`` inputs would be valid (and equivalent)::
 
-            {
-             'Clock': [
-                 {'time': 0.0, 'value': -0.5},
-                 {'time': 1.0, 'value': 0.5},
-                 {'time': 3.0, 'value': -1.5},
-             ],
-             'Microwave': [
-                 {'time': 0.5, 'value': 0.5 + 1.5j},
-                 {'time': 2.0, 'value': 0.2 - 0.3j},
-             ],
+            controls={
+              "Clock": {"times": [0.0, 0.5, 1.5, 2.0], "values": [0.1, 0.3, 0.2, 0.4]},
+              "Microwave": {"times": [0.0, 1.0, 2.0], "values": [0.5 + 0.5j, 0.3, 0.2 - 0.3j]},
             }
+
+            controls={
+              'Clock': [
+                {'time': 0.0, 'value': 0.1},
+                {'time': 0.5, 'value': 0.3},
+                {'time': 1.5, 'value': 0.2},
+                {'time': 2.0, 'value': 0.4},
+              ],
+              'Microwave': [
+                {'time': 0.0, 'value': 0.5 + 0.5j},
+                {'time': 1.0, 'value': 0.3},
+                {'time': 2.0, 'value': 0.2 - 0.3j},
+              ],
+            }
+
     polar : bool, optional
         The mode of the plot when the values appear to be complex numbers.
         Plot magnitude and angle in two figures if set to True, otherwise plot I and Q
@@ -202,12 +223,19 @@ def plot_smooth_controls(
         If any of the input parameters are invalid.
     """
     plots_data: List[Any] = []
-    for name, samples in controls.items():
-        times = []
-        values = []
-        for sample in samples:
-            times.append(sample["time"])
-            values.append(sample["value"])
+    for name, control in controls.items():
+        # Process each control depending whether it's passed as a list of samples...
+        if isinstance(control, list):
+            times = []
+            values = []
+            for sample in control:
+                times.append(sample["time"])
+                values.append(sample["value"])
+        # ...or a times/values dictionary.
+        else:
+            times = control["times"]
+            values = control["values"]
+        # Create plot data for the control.
         values = np.array(values)
         plots_data = plots_data + _create_plots_data_from_control(
             name, times, values, polar, unit_symbol, two_pi_factor
