@@ -27,6 +27,18 @@ from matplotlib.style import context
 BORDER_COLOR = "#D8E0E9"
 TEXT_COLOR = "#6C5C71"
 
+QCTRL_STYLE_COLORS = [
+    "#680CE9",
+    "#FA7370",
+    "#3CCBC5",
+    "#E181F3",
+    "#D4CD52",
+    "#76AAEF",
+    "#F2995B",
+    "#F373C0",
+    "#40D066",
+]
+
 
 def get_qctrl_style() -> Dict[str, Any]:
     """
@@ -63,19 +75,7 @@ def get_qctrl_style() -> Dict[str, Any]:
 
     style["lines.color"] = BORDER_COLOR
 
-    style["axes.prop_cycle"] = cycler(
-        color=[
-            "#680CE9",
-            "#EB6467",
-            "#57CDC8",
-            "#E583F7",
-            "#CECF58",
-            "#64A0EB",
-            "#E98C55",
-            "#EB64B6",
-            "#57CD71",
-        ]
-    )
+    style["axes.prop_cycle"] = cycler(color=QCTRL_STYLE_COLORS)
 
     return style
 
